@@ -13,7 +13,13 @@ test_that("max_prefix_length works", {
 })
 
 test_that("input validation works", {
-  expect_error(is_ipv4(1L), "`x` must be an ip_address or ip_network vector")
-  expect_error(is_ipv6(1L), "`x` must be an ip_address or ip_network vector")
-  expect_error(max_prefix_length(1L), "`x` must be an ip_address or ip_network vector")
+  expect_snapshot(error = TRUE, {
+    is_ipv4(1L)
+  })
+  expect_snapshot(error = TRUE, {
+    is_ipv6(1L)
+  })
+  expect_snapshot(error = TRUE, {
+    max_prefix_length(1L)
+  })
 })
